==> openshift-model-5.8.1-sources.jar: io/fabric8/openshift/api/model/ProjectFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProjectFluent<A extends io.fabric8.openshift.api.model.ProjectFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ProjectSpec getSpec();
  public io.fabric8.openshift.api.model.ProjectSpec buildSpec();
  public A withSpec(io.fabric8.openshift.api.model.ProjectSpec spec);
  public java.lang.Boolean hasSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> withNewSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.ProjectSpec item);
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editOrNewSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.ProjectSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ProjectStatus getStatus();
  public io.fabric8.openshift.api.model.ProjectStatus buildStatus();
  public A withStatus(io.fabric8.openshift.api.model.ProjectStatus status);
  public java.lang.Boolean hasStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> withNewStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.ProjectStatus item);
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editOrNewStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.ProjectStatus item);
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ProjectSpecFluent<io.fabric8.openshift.api.model.ProjectFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ProjectStatusFluent<io.fabric8.openshift.api.model.ProjectFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ProjectFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ProjectFluent<A extends io.fabric8.openshift.api.model.ProjectFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata();
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata();
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata);
  public java.lang.Boolean hasMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> withNewMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editOrNewMetadata();
  public io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ProjectSpec getSpec();
  public io.fabric8.openshift.api.model.ProjectSpec buildSpec();
  public A withSpec(io.fabric8.openshift.api.model.ProjectSpec spec);
  public java.lang.Boolean hasSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> withNewSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> withNewSpecLike(io.fabric8.openshift.api.model.ProjectSpec item);
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editOrNewSpec();
  public io.fabric8.openshift.api.model.ProjectFluent.SpecNested<A> editOrNewSpecLike(io.fabric8.openshift.api.model.ProjectSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.ProjectStatus getStatus();
  public io.fabric8.openshift.api.model.ProjectStatus buildStatus();
  public A withStatus(io.fabric8.openshift.api.model.ProjectStatus status);
  public java.lang.Boolean hasStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> withNewStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> withNewStatusLike(io.fabric8.openshift.api.model.ProjectStatus item);
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editOrNewStatus();
  public io.fabric8.openshift.api.model.ProjectFluent.StatusNested<A> editOrNewStatusLike(io.fabric8.openshift.api.model.ProjectStatus item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectMetaFluent<io.fabric8.openshift.api.model.ProjectFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ProjectSpecFluent<io.fabric8.openshift.api.model.ProjectFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ProjectStatusFluent<io.fabric8.openshift.api.model.ProjectFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
